#line 2 "albumtheme-lex.c"

#line 4 "albumtheme-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer gth_albumtheme_yy_create_buffer
#define yy_delete_buffer gth_albumtheme_yy_delete_buffer
#define yy_flex_debug gth_albumtheme_yy_flex_debug
#define yy_init_buffer gth_albumtheme_yy_init_buffer
#define yy_flush_buffer gth_albumtheme_yy_flush_buffer
#define yy_load_buffer_state gth_albumtheme_yy_load_buffer_state
#define yy_switch_to_buffer gth_albumtheme_yy_switch_to_buffer
#define yyin gth_albumtheme_yyin
#define yyleng gth_albumtheme_yyleng
#define yylex gth_albumtheme_yylex
#define yylineno gth_albumtheme_yylineno
#define yyout gth_albumtheme_yyout
#define yyrestart gth_albumtheme_yyrestart
#define yytext gth_albumtheme_yytext
#define yywrap gth_albumtheme_yywrap
#define yyalloc gth_albumtheme_yyalloc
#define yyrealloc gth_albumtheme_yyrealloc
#define yyfree gth_albumtheme_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE gth_albumtheme_yyrestart(gth_albumtheme_yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t gth_albumtheme_yyleng;

extern FILE *gth_albumtheme_yyin, *gth_albumtheme_yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gth_albumtheme_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up gth_albumtheme_yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via gth_albumtheme_yyrestart()), so that the user can continue scanning by
	 * just pointing gth_albumtheme_yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when gth_albumtheme_yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t gth_albumtheme_yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow gth_albumtheme_yywrap()'s to do buffer switches
 * instead of setting up a fresh gth_albumtheme_yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void gth_albumtheme_yyrestart (FILE *input_file  );
void gth_albumtheme_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE gth_albumtheme_yy_create_buffer (FILE *file,int size  );
void gth_albumtheme_yy_delete_buffer (YY_BUFFER_STATE b  );
void gth_albumtheme_yy_flush_buffer (YY_BUFFER_STATE b  );
void gth_albumtheme_yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void gth_albumtheme_yypop_buffer_state (void );

static void gth_albumtheme_yyensure_buffer_stack (void );
static void gth_albumtheme_yy_load_buffer_state (void );
static void gth_albumtheme_yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER gth_albumtheme_yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE gth_albumtheme_yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE gth_albumtheme_yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE gth_albumtheme_yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *gth_albumtheme_yyalloc (yy_size_t  );
void *gth_albumtheme_yyrealloc (void *,yy_size_t  );
void gth_albumtheme_yyfree (void *  );

#define yy_new_buffer gth_albumtheme_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        gth_albumtheme_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gth_albumtheme_yy_create_buffer(gth_albumtheme_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        gth_albumtheme_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gth_albumtheme_yy_create_buffer(gth_albumtheme_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *gth_albumtheme_yyin = (FILE *) 0, *gth_albumtheme_yyout = (FILE *) 0;

typedef int yy_state_type;

extern int gth_albumtheme_yylineno;

int gth_albumtheme_yylineno = 1;

extern char *gth_albumtheme_yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr gth_albumtheme_yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up gth_albumtheme_yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	gth_albumtheme_yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 41
#define YY_END_OF_BUFFER 42
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[186] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       11,   11,   42,   40,   39,   41,    8,   38,   12,   41,
        9,   16,   15,   24,   41,   25,   26,   22,   20,   27,
       21,   41,   23,   36,   18,   17,   19,   37,   37,   41,
       13,   11,   10,   40,    0,    8,   14,   15,   31,   28,
       34,   36,   32,   30,   33,   37,   35,   29,   11,   40,
        0,    7,   40,    0,    0,    0,    0,   40,    0,    0,
        0,    1,    0,   40,    0,    4,    0,    0,   40,    3,
        0,    0,    0,   40,    2,    0,    0,   40,    0,    0,
       40,    0,    5,   40,    6,   40,   40,   40,   40,   40,

       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    2,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    4,    5,    1,    1,    6,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   18,    1,   19,
       20,   21,    1,    1,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
        1,    1,    1,    1,   23,    1,   24,   22,   25,   26,

       27,   28,   22,   29,   30,   22,   22,   31,   22,   32,
       33,   22,   22,   34,   35,   36,   22,   37,   22,   22,
       22,   22,    1,   38,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[39] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    1,    1,
        1,    1,    1,    3,    4,    1,    4,    4,    5,    1,
        1,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    1
    } ;

static yyconst flex_uint16_t yy_base[291] =
    {   0,
      558,  557,    0,    0,   38,    0,   76,    0,  110,  112,
      567,  566,  573,    0,  566,  578,    0,  578,  578,  550,
      578,  578,    0,  550,  562,  578,  578,  578,  578,  578,
      578,  553,  578,  550,  546,  545,  544,    0,  531,  524,
      578,    0,  578,    0,  116,    0,  578,    0,  578,  578,
      578,  544,  578,  578,  578,    0,    0,  578,    0,    0,
       93,  578,    0,   93,  527,  531,  531,    0,  522,  530,
      521,  578,  518,    0,   99,  578,  530,  529,    0,  578,
      128,  108,   97,    0,  578,  109,  108,    0,  106,   96,
        0,   98,  578,    0,  578,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  578,  578,  136,  141,  146,  148,  150,
      118,  154,  159,  163,  167,  171,  175,  179,  183,  187,

      191,  195,  199,  203,  207,  211,  215,  219,  223,  227,
      231,  235,  239,  243,  247,  251,  255,  259,  263,  267,
      271,  275,  279,  283,  287,  291,  295,  299,  303,  307,
      311,  315,  319,  323,  327,  331,  335,  339,  343,  347,
      351,  355,  359,  363,  367,  371,  375,  379,  383,  387,
      391,  395,  399,  403,  407,  411,  415,  419,  423,  427,
      431,  435,  439,  443,  447,  451,  455,  459,  463,  467,
      471,  475,  479,  483,  487,  491,  495,  499,  503,  507,
      511,  515,  519,  523,  527,  531,  535,  539,  543,  547
    } ;

static yyconst flex_int16_t yy_def[291] =
    {   0,
      186,  186,  185,    3,  185,    5,  185,    7,    7,    7,
      187,  187,  185,  188,  185,  185,  189,  185,  185,  185,
      185,  185,  190,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  191,  191,  185,
      185,  192,  185,  193,  185,  189,  185,  190,  185,  185,
      185,  185,  185,  185,  185,  191,  191,  185,  192,  194,
      185,  185,  195,  185,  185,  185,  185,  196,  185,  185,
      185,  185,  185,  197,  185,  185,  185,  185,  198,  185,
      185,  185,  185,  199,  185,  185,  185,  200,  185,  185,
      201,  185,  185,  202,  185,  203,  204,  205,  206,  207,

      208,  209,  210,  211,  212,  213,  214,  215,  216,  217,
      218,  219,  220,  221,  222,  223,  224,  225,  226,  227,
      228,  229,  230,  231,  232,  233,  234,  235,  236,  237,
      238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
      248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
      258,  259,  260,  261,  262,  263,  264,  265,  266,  267,
      268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
      278,  279,  280,  281,  282,  283,  284,  285,  286,  287,
      288,  289,  290,  185,    0,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,

      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185
    } ;

static yyconst flex_uint16_t yy_nxt[617] =
    {   0,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       16,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   16,   16,   18,
       18,   16,   19,   20,   16,   21,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   22,   16,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   16,   16,   18,   18,   24,
       16,   20,   25,   21,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   16,   35,   36,   37,   38,   38,   38,

       38,   38,   38,   38,   38,   39,   38,   38,   38,   38,
       38,   38,   38,   40,   41,   16,   41,   16,   61,   64,
       65,   56,   66,   69,   70,   80,   95,   67,   81,   93,
       92,   90,   89,   87,   86,   62,   14,   14,   14,   14,
       14,   42,   42,   42,   42,   42,   44,   44,   44,   44,
       46,   46,   48,   48,   59,   85,   59,   59,   59,   60,
       60,   60,   60,   63,   63,   63,   63,   68,   68,   68,
       68,   74,   74,   74,   74,   79,   79,   79,   79,   84,
       84,   84,   84,   88,   88,   88,   88,   91,   91,   91,
       91,   94,   94,   94,   94,   96,   96,   96,   96,   97,

       97,   97,   97,   98,   98,   98,   98,   99,   99,   99,
       99,  100,  100,  100,  100,  101,  101,  101,  101,  102,
      102,  102,  102,  103,  103,  103,  103,  104,  104,  104,
      104,  105,  105,  105,  105,  106,  106,  106,  106,  107,
      107,  107,  107,  108,  108,  108,  108,  109,  109,  109,
      109,  110,  110,  110,  110,  111,  111,  111,  111,  112,
      112,  112,  112,  113,  113,  113,  113,  114,  114,  114,
      114,  115,  115,  115,  115,  116,  116,  116,  116,  117,
      117,  117,  117,  118,  118,  118,  118,  119,  119,  119,
      119,  120,  120,  120,  120,  121,  121,  121,  121,  122,

      122,  122,  122,  123,  123,  123,  123,  124,  124,  124,
      124,  125,  125,  125,  125,  126,  126,  126,  126,  127,
      127,  127,  127,  128,  128,  128,  128,  129,  129,  129,
      129,  130,  130,  130,  130,  131,  131,  131,  131,  132,
      132,  132,  132,  133,  133,  133,  133,  134,  134,  134,
      134,  135,  135,  135,  135,  136,  136,  136,  136,  137,
      137,  137,  137,  138,  138,  138,  138,  139,  139,  139,
      139,  140,  140,  140,  140,  141,  141,  141,  141,  142,
      142,  142,  142,  143,  143,  143,  143,  144,  144,  144,
      144,  145,  145,  145,  145,  146,  146,  146,  146,  147,

      147,  147,  147,  148,  148,  148,  148,  149,  149,  149,
      149,  150,  150,  150,  150,  151,  151,  151,  151,  152,
      152,  152,  152,  153,  153,  153,  153,  154,  154,  154,
      154,  155,  155,  155,  155,  156,  156,  156,  156,  157,
      157,  157,  157,  158,  158,  158,  158,  159,  159,  159,
      159,  160,  160,  160,  160,  161,  161,  161,  161,  162,
      162,  162,  162,  163,  163,  163,  163,  164,  164,  164,
      164,  165,  165,  165,  165,  166,  166,  166,  166,  167,
      167,  167,  167,  168,  168,  168,  168,  169,  169,  169,
      169,  170,  170,  170,  170,  171,  171,  171,  171,  172,

      172,  172,  172,  173,  173,  173,  173,  174,  174,  174,
      174,  175,  175,  175,  175,  176,  176,  176,  176,  177,
      177,  177,  177,  178,  178,  178,  178,  179,  179,  179,
      179,  180,  180,  180,  180,  181,  181,  181,  181,  182,
      182,  182,  182,  183,  183,  183,  183,  184,  184,  184,
      184,   83,   82,   78,   77,   76,   75,   73,   72,   71,
       52,   58,   57,   55,   54,   53,   52,   51,   50,   49,
       47,   45,  185,   43,   43,   15,   15,   13,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,

      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185
    } ;

static yyconst flex_int16_t yy_chk[617] =
    {   0,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    9,    9,   10,   10,   45,   61,
       61,  191,   61,   64,   64,   75,   92,   61,   75,   90,
       89,   87,   86,   83,   82,   45,  186,  186,  186,  186,
      186,  187,  187,  187,  187,  187,  188,  188,  188,  188,
      189,  189,  190,  190,  192,   81,  192,  192,  192,  193,
      193,  193,  193,  194,  194,  194,  194,  195,  195,  195,
      195,  196,  196,  196,  196,  197,  197,  197,  197,  198,
      198,  198,  198,  199,  199,  199,  199,  200,  200,  200,
      200,  201,  201,  201,  201,  202,  202,  202,  202,  203,

      203,  203,  203,  204,  204,  204,  204,  205,  205,  205,
      205,  206,  206,  206,  206,  207,  207,  207,  207,  208,
      208,  208,  208,  209,  209,  209,  209,  210,  210,  210,
      210,  211,  211,  211,  211,  212,  212,  212,  212,  213,
      213,  213,  213,  214,  214,  214,  214,  215,  215,  215,
      215,  216,  216,  216,  216,  217,  217,  217,  217,  218,
      218,  218,  218,  219,  219,  219,  219,  220,  220,  220,
      220,  221,  221,  221,  221,  222,  222,  222,  222,  223,
      223,  223,  223,  224,  224,  224,  224,  225,  225,  225,
      225,  226,  226,  226,  226,  227,  227,  227,  227,  228,

      228,  228,  228,  229,  229,  229,  229,  230,  230,  230,
      230,  231,  231,  231,  231,  232,  232,  232,  232,  233,
      233,  233,  233,  234,  234,  234,  234,  235,  235,  235,
      235,  236,  236,  236,  236,  237,  237,  237,  237,  238,
      238,  238,  238,  239,  239,  239,  239,  240,  240,  240,
      240,  241,  241,  241,  241,  242,  242,  242,  242,  243,
      243,  243,  243,  244,  244,  244,  244,  245,  245,  245,
      245,  246,  246,  246,  246,  247,  247,  247,  247,  248,
      248,  248,  248,  249,  249,  249,  249,  250,  250,  250,
      250,  251,  251,  251,  251,  252,  252,  252,  252,  253,

      253,  253,  253,  254,  254,  254,  254,  255,  255,  255,
      255,  256,  256,  256,  256,  257,  257,  257,  257,  258,
      258,  258,  258,  259,  259,  259,  259,  260,  260,  260,
      260,  261,  261,  261,  261,  262,  262,  262,  262,  263,
      263,  263,  263,  264,  264,  264,  264,  265,  265,  265,
      265,  266,  266,  266,  266,  267,  267,  267,  267,  268,
      268,  268,  268,  269,  269,  269,  269,  270,  270,  270,
      270,  271,  271,  271,  271,  272,  272,  272,  272,  273,
      273,  273,  273,  274,  274,  274,  274,  275,  275,  275,
      275,  276,  276,  276,  276,  277,  277,  277,  277,  278,

      278,  278,  278,  279,  279,  279,  279,  280,  280,  280,
      280,  281,  281,  281,  281,  282,  282,  282,  282,  283,
      283,  283,  283,  284,  284,  284,  284,  285,  285,  285,
      285,  286,  286,  286,  286,  287,  287,  287,  287,  288,
      288,  288,  288,  289,  289,  289,  289,  290,  290,  290,
      290,   78,   77,   73,   71,   70,   69,   67,   66,   65,
       52,   40,   39,   37,   36,   35,   34,   32,   25,   24,
       20,   15,   13,   12,   11,    2,    1,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,

      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int gth_albumtheme_yy_flex_debug;
int gth_albumtheme_yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *gth_albumtheme_yytext;
#line 1 "albumtheme.l"
#line 2 "albumtheme.l"
/*
 *  Pix
 *
 *  Copyright (C) 2003, 2010 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#include <glib.h>
#include <gio/gio.h>

GFileInputStream *yy_istream;

#undef YY_INPUT
#define YY_INPUT(buf,result,max_size)									\
{													\
	gssize n = g_input_stream_read (G_INPUT_STREAM (yy_istream), buf, max_size, NULL, NULL);	\
	result = (n <= 0 ? YY_NULL : n);								\
}

static int before_string = 0; /* the start condition before entering in STRING */

#define YY_NO_INPUT 1

#line 738 "albumtheme-lex.c"

#define INITIAL 0
#define FUNCTION 1
#define ATTRIBUTES 2
#define CONDITION 3
#define QUOTE 4
#define STRING 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int gth_albumtheme_yylex_destroy (void );

int gth_albumtheme_yyget_debug (void );

void gth_albumtheme_yyset_debug (int debug_flag  );

YY_EXTRA_TYPE gth_albumtheme_yyget_extra (void );

void gth_albumtheme_yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *gth_albumtheme_yyget_in (void );

void gth_albumtheme_yyset_in  (FILE * _in_str  );

FILE *gth_albumtheme_yyget_out (void );

void gth_albumtheme_yyset_out  (FILE * _out_str  );

yy_size_t gth_albumtheme_yyget_leng (void );

char *gth_albumtheme_yyget_text (void );

int gth_albumtheme_yyget_lineno (void );

void gth_albumtheme_yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int gth_albumtheme_yywrap (void );
#else
extern int gth_albumtheme_yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( gth_albumtheme_yytext, gth_albumtheme_yyleng, 1, gth_albumtheme_yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( gth_albumtheme_yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( gth_albumtheme_yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, gth_albumtheme_yyin))==0 && ferror(gth_albumtheme_yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(gth_albumtheme_yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int gth_albumtheme_yylex (void);

#define YY_DECL int gth_albumtheme_yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after gth_albumtheme_yytext and gth_albumtheme_yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! gth_albumtheme_yyin )
			gth_albumtheme_yyin = stdin;

		if ( ! gth_albumtheme_yyout )
			gth_albumtheme_yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			gth_albumtheme_yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				gth_albumtheme_yy_create_buffer(gth_albumtheme_yyin,YY_BUF_SIZE );
		}

		gth_albumtheme_yy_load_buffer_state( );
		}

	{
#line 47 "albumtheme.l"


#line 962 "albumtheme-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of gth_albumtheme_yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 186 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 578 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 49 "albumtheme.l"
{
					BEGIN (CONDITION);
					return IF;
				}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 53 "albumtheme.l"
{
					BEGIN (CONDITION);
					return ELSE_IF;
				}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 57 "albumtheme.l"
{
					BEGIN (ATTRIBUTES);
					return ELSE;
				}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 61 "albumtheme.l"
{
					BEGIN (ATTRIBUTES);
					return END;
				}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 65 "albumtheme.l"
{
					BEGIN (ATTRIBUTES);
					return SET_VAR;
				}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 69 "albumtheme.l"
{
					BEGIN (CONDITION);
					yylval.ivalue = GTH_TAG_FOR_EACH_IN_RANGE;
					return FOR_EACH;
				}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 74 "albumtheme.l"
{
					BEGIN (FUNCTION);
					return PRINT;
				}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 78 "albumtheme.l"
{
					if (g_str_equal (gth_albumtheme_yytext, "eval") || g_str_equal (gth_albumtheme_yytext, "translate")) 
						BEGIN (CONDITION);
					else
						BEGIN (ATTRIBUTES);
					yylval.text = g_strdup (gth_albumtheme_yytext);
					return FUNCTION_NAME;
				}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 86 "albumtheme.l"
{
					before_string = YY_START;
					BEGIN (STRING);
					return '\'';
				}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 91 "albumtheme.l"
{
					BEGIN (before_string);
					return '\'';
				}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 95 "albumtheme.l"
{
					yylval.text = g_strdup (gth_albumtheme_yytext);
					return QUOTED_STRING;
				}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 99 "albumtheme.l"
{
					BEGIN (QUOTE);
					return '"';
				}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 103 "albumtheme.l"
{
					BEGIN (ATTRIBUTES);
					return '"';
				}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 107 "albumtheme.l"
{
					BEGIN (INITIAL);
					return END_TAG;
				}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 111 "albumtheme.l"
{
					yylval.text = g_strdup (gth_albumtheme_yytext);
					return ATTRIBUTE_NAME;
				}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 115 "albumtheme.l"
{
					return '=';
				}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 118 "albumtheme.l"
{
					return '=';
				}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 121 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_CMP_LT;
					return COMPARE;
				}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 125 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_CMP_GT;
					return COMPARE;
				}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 129 "albumtheme.l"
{
					return '+';
				}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 132 "albumtheme.l"
{
					return '-';
				}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 135 "albumtheme.l"
{
					return '*';
				}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 138 "albumtheme.l"
{
					return '/';
				}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 141 "albumtheme.l"
{
					return '!';
				}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 144 "albumtheme.l"
{
					return '(';
				}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 147 "albumtheme.l"
{
					return ')';
				}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 150 "albumtheme.l"
{
					return ',';
				}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 153 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_AND;
					return BOOL_OP;
				}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 157 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_OR;
					return BOOL_OP;
				}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 161 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_CMP_EQ;
					return COMPARE;
				}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 165 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_CMP_NE;
					return COMPARE;
				}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 169 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_CMP_LE;
					return COMPARE;
				}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 173 "albumtheme.l"
{
					yylval.ivalue = GTH_OP_CMP_GE;
					return COMPARE;
				}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 177 "albumtheme.l"
{
					return RANGE;
				}				
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 180 "albumtheme.l"
{
					return IN;
				}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 183 "albumtheme.l"
{
					yylval.ivalue = atoi (gth_albumtheme_yytext);
					return NUMBER;
				}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 187 "albumtheme.l"
{
					yylval.text = g_strdup (gth_albumtheme_yytext);
					return VARIABLE;
				}		
	YY_BREAK
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
#line 191 "albumtheme.l"
{
					/* Eat spaces inside tag. */
				}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 194 "albumtheme.l"
{
					yylval.text = g_strdup (gth_albumtheme_yytext);
					return HTML;
				}
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 198 "albumtheme.l"
{
					yylval.text = g_strdup (gth_albumtheme_yytext);
					return HTML;
				}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(FUNCTION):
case YY_STATE_EOF(ATTRIBUTES):
case YY_STATE_EOF(CONDITION):
case YY_STATE_EOF(QUOTE):
case YY_STATE_EOF(STRING):
#line 202 "albumtheme.l"
{
					YY_FLUSH_BUFFER;
					BEGIN(INITIAL);
					yyterminate ();
				}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 208 "albumtheme.l"
ECHO;
	YY_BREAK
#line 1353 "albumtheme-lex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed gth_albumtheme_yyin at a new source and called
			 * gth_albumtheme_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = gth_albumtheme_yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( gth_albumtheme_yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * gth_albumtheme_yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of gth_albumtheme_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	yy_size_t number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					gth_albumtheme_yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			gth_albumtheme_yyrestart(gth_albumtheme_yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) gth_albumtheme_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 186 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 186 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 185);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					gth_albumtheme_yyrestart(gth_albumtheme_yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( gth_albumtheme_yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve gth_albumtheme_yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void gth_albumtheme_yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        gth_albumtheme_yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            gth_albumtheme_yy_create_buffer(gth_albumtheme_yyin,YY_BUF_SIZE );
	}

	gth_albumtheme_yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	gth_albumtheme_yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void gth_albumtheme_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		gth_albumtheme_yypop_buffer_state();
	 *		gth_albumtheme_yypush_buffer_state(new_buffer);
     */
	gth_albumtheme_yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	gth_albumtheme_yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (gth_albumtheme_yywrap()) processing, but the only time this flag
	 * is looked at is after gth_albumtheme_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void gth_albumtheme_yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	gth_albumtheme_yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE gth_albumtheme_yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) gth_albumtheme_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gth_albumtheme_yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) gth_albumtheme_yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in gth_albumtheme_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	gth_albumtheme_yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with gth_albumtheme_yy_create_buffer()
 * 
 */
    void gth_albumtheme_yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		gth_albumtheme_yyfree((void *) b->yy_ch_buf  );

	gth_albumtheme_yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a gth_albumtheme_yyrestart() or at EOF.
 */
    static void gth_albumtheme_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	gth_albumtheme_yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then gth_albumtheme_yy_init_buffer was _probably_
     * called from gth_albumtheme_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void gth_albumtheme_yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		gth_albumtheme_yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void gth_albumtheme_yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	gth_albumtheme_yyensure_buffer_stack();

	/* This block is copied from gth_albumtheme_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from gth_albumtheme_yy_switch_to_buffer. */
	gth_albumtheme_yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void gth_albumtheme_yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	gth_albumtheme_yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		gth_albumtheme_yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void gth_albumtheme_yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)gth_albumtheme_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gth_albumtheme_yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)gth_albumtheme_yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gth_albumtheme_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE gth_albumtheme_yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) gth_albumtheme_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gth_albumtheme_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	gth_albumtheme_yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to gth_albumtheme_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       gth_albumtheme_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE gth_albumtheme_yy_scan_string (yyconst char * yystr )
{
    
	return gth_albumtheme_yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to gth_albumtheme_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE gth_albumtheme_yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) gth_albumtheme_yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in gth_albumtheme_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = gth_albumtheme_yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in gth_albumtheme_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gth_albumtheme_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		gth_albumtheme_yytext[gth_albumtheme_yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = gth_albumtheme_yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		gth_albumtheme_yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int gth_albumtheme_yyget_lineno  (void)
{
        
    return gth_albumtheme_yylineno;
}

/** Get the input stream.
 * 
 */
FILE *gth_albumtheme_yyget_in  (void)
{
        return gth_albumtheme_yyin;
}

/** Get the output stream.
 * 
 */
FILE *gth_albumtheme_yyget_out  (void)
{
        return gth_albumtheme_yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t gth_albumtheme_yyget_leng  (void)
{
        return gth_albumtheme_yyleng;
}

/** Get the current token.
 * 
 */

char *gth_albumtheme_yyget_text  (void)
{
        return gth_albumtheme_yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void gth_albumtheme_yyset_lineno (int  _line_number )
{
    
    gth_albumtheme_yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see gth_albumtheme_yy_switch_to_buffer
 */
void gth_albumtheme_yyset_in (FILE *  _in_str )
{
        gth_albumtheme_yyin = _in_str ;
}

void gth_albumtheme_yyset_out (FILE *  _out_str )
{
        gth_albumtheme_yyout = _out_str ;
}

int gth_albumtheme_yyget_debug  (void)
{
        return gth_albumtheme_yy_flex_debug;
}

void gth_albumtheme_yyset_debug (int  _bdebug )
{
        gth_albumtheme_yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from gth_albumtheme_yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    gth_albumtheme_yyin = stdin;
    gth_albumtheme_yyout = stdout;
#else
    gth_albumtheme_yyin = (FILE *) 0;
    gth_albumtheme_yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * gth_albumtheme_yylex_init()
     */
    return 0;
}

/* gth_albumtheme_yylex_destroy is for both reentrant and non-reentrant scanners. */
int gth_albumtheme_yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		gth_albumtheme_yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		gth_albumtheme_yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	gth_albumtheme_yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * gth_albumtheme_yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *gth_albumtheme_yyalloc (yy_size_t  size )
{
			return (void *) malloc( size );
}

void *gth_albumtheme_yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void gth_albumtheme_yyfree (void * ptr )
{
			free( (char *) ptr );	/* see gth_albumtheme_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 208 "albumtheme.l"



